


RMAS_BUS_WSDL='http://localhost:7789/?wsdl'
POLL_INTERVAL=5000
EVENTS=[
        ('ethics-approved', 'handlers.ethics_approved'),
        ]


PM_API_PROPOSAL_ENDPOINT = 'http://0.0.0.0:3000/proposals'